@@ -1,20 +1,28 @@
 # from .agents.autogen import AutoGenAgent
 # from .agents.local import LocalAIAgent
+import os
+
 from .agents.mockai import MockAIAgent
 from .agents.openai import OpenAIAgent
 
 
 class AutoTeam:
     def __init__(self, model=None):
-        self.proxy = None
-        # if model == "autogen":
-        #     self.proxy = AutoGenAgent()
-        # if model == "local":
-        #     self.proxy = LocalAIAgent()
-        if model == "openai":
-            self.proxy = OpenAIAgent()
-        if not self.proxy:
-            self.proxy = MockAIAgent()
+        if model:
+            self.proxy = model()
+        else:
+            model = os.getenv("AI_AGENT", "openai")
+            self.proxy = None
+            # if model == "autogen":
+            #     self.proxy = AutoGenAgent()
+            # if model == "local":
+            #     self.proxy = LocalAIAgent()
+            if model == "openai":
+                self.proxy = OpenAIAgent()
+            elif model == "mockai":
+                self.proxy = MockAIAgent()
+            else:
+                raise Exception("Invalid model")
 
     def generate_image(self, prompt, **kwargs):
         return self.proxy.generate_image(prompt, **kwargs)
