@@ -12,3 +12,8 @@ class Config:
     DEBUG = os.environ.get("DEBUG", False)
     TESTING = os.environ.get("TESTING", False)
     TRAP_HTTP_EXCEPTIONS = os.environ.get("TRAP_HTTP_EXCEPTIONS", False)
+
+
+class APIConfig(Config):
+    APP_NAME = os.environ.get("APP_NAME", __name__) + "API"
+    RQ_DASHBOARD_REDIS_URL = f"redis://{os.environ.get('REDIS_HOST', 'redis')}:{os.environ.get('REDIS_PORT', '6379')}"
