@@ -1,7 +1,6 @@
 import time
 
 from autonomous import log
-from autonomous.tasks import AutoTasks
 
 
 def mocktask():
@@ -25,6 +24,6 @@ def parametermocktask(*args, **kwargs):
     return result
 
 
-def errormocktask():
-    log("ErrorMockTask - Starting")
-    raise Exception("ErrorMockTask")
+def errormocktask(a, b):
+    time.sleep(2)
+    return int(a) + str(b)
