@@ -10,7 +10,7 @@ from autonomous.auth.user import AutoUser
 
 
 class TestAuth:
-    def test_google_auth(self, client):
+    def test_google_auth(self):
         auth = GoogleAuth()
         uri, status = auth.authenticate()
         log(uri, status)
@@ -25,7 +25,7 @@ class TestAuth:
         assert status
 
     def test_user(self):
-        AutoModel.table().flush_table()
+        AutoUser.table().flush_table()
         user_info = {
             "name": "test",
             "email": "test@test.com",
@@ -33,4 +33,5 @@ class TestAuth:
         }
         user = AutoUser.authenticate(user_info)
         user2 = AutoUser.authenticate(user_info)
+        assert user.pk == user2.save()
         assert user.pk == user2.pk
