@@ -11,7 +11,6 @@ from autonomous.auth.user import AutoUser
 
 
 class AutoAuth:
-    user = None
     user_class = AutoUser
 
     def __init__(
@@ -47,9 +46,10 @@ class AutoAuth:
         """
         Returns the current user.
         """
-        if session.get("user") and not cls.user:
-            cls.user = AutoAuth.user_class(**session["user"])
-        return cls.user
+        user = cls.user_class.get_guest()
+        if session.get("user") and session["user"]["state"] == "authenticated":
+            user = cls.user_class.get(session["user"].get("pk"))
+        return user
 
     def authenticate(self):
         """
@@ -94,31 +94,16 @@ class AutoAuth:
         def wrap(func):
             @wraps(func)
             def decorated_view(*args, **kwargs):
-                if current_app:
-                    # log(cls.user, session.get("user"))
-                    if (
-                        session.get("user")
-                        and session["user"]["state"] == "authenticated"
-                    ):
-                        cls.user = cls.user_class(**session.get("user"))
-                        cls.user.last_login = datetime.now()
-                        cls.user.save()
-                        session["user"] = cls.user.serialize()
-                        return func(*args, **kwargs)
-                    elif guest:
-                        cls.user = cls.user_class.find(
-                            email="guest@world.stevenamoore.dev"
-                        )
-                        if not cls.user:
-                            cls.user = cls.user_class(
-                                name="Guest",
-                                email="guest@world.stevenamoore.dev",
-                                state="guest",
-                            )
-                        session["user"] = cls.user.serialize()
-                        return func(*args, **kwargs)
-                    else:
-                        return redirect(url_for("auth.login"))
+                # log(session.get("user"))
+                user = cls.current_user()
+                if user.state == "authenticated":
+                    user.last_login = datetime.now()
+                    user.save()
+                session["user"] = user.serialize()
+
+                if not guest and user.is_guest:
+                    return redirect(url_for("auth.login"))
+                return func(*args, **kwargs)
 
             return decorated_view
 
