@@ -153,7 +153,11 @@ class Table:
         try:
             json_db = self._db.json()
             json_db.set(f"{self.name}:{obj['pk']}", Path.root_path(), obj)
+        except TypeError as e:
+            log(e)
+            raise e
         except Exception as e:
+            # log(obj)
             raise e
         obj = {k: self._validate(k, v, decode=True) for k, v in obj.items()}
         return obj["pk"]
@@ -232,8 +236,13 @@ class Table:
 
     def random(self):
         keys = self._db.keys(f"{self.name}:*")
-        key = random.choice(keys).split(":")[-1]
-        return self.get(key)
+        try:
+            key = random.choice(keys).split(":")[-1]
+        except Exception as e:
+            # log(e, f"Table '{self.name}' is empty.")
+            return None
+        else:
+            return self.get(key)
 
     def clear(self):
         # breakpoint()
