@@ -1,7 +1,9 @@
 # opt : Optional[str]  # for optional attributes
 # default : Optional[str] = "value"  # for default values
+import copy
 import importlib
 import json
+import uuid
 from abc import ABC
 from datetime import datetime
 
@@ -28,13 +30,14 @@ class DelayedModel:
             _pk = object.__getattribute__(self, "_delayed_pk")
             _model = object.__getattribute__(self, "_delayed_model")
             # log(_pk, _model)
+            # breakpoint()
             _obj = _model.get(_pk)
             # log(_obj)
             try:
                 assert _obj
             except AssertionError as e:
                 msg = f"{e}\n\nModel relationship error. Most likely failed to clean up dangling reference.\nModel: {_model}\npk: {_pk}\nResult: {_obj}"
-                log(msg)
+                # log(msg)
                 raise Exception(msg)
             else:
                 object.__setattr__(self, "_delayed_obj", _obj)
@@ -72,8 +75,7 @@ class DelayedModel:
 
     def __repr__(self):
         result = repr(self._delayed_obj)
-        msg = f"<<DelayedModel {self._delayed_model.__name__}:{self._delayed_pk}>>\n"
-        msg += f"{result}\n\n"
+        msg = f"\n<<DelayedModel {self._delayed_model.__name__}:{self._delayed_pk}>>:\t{result}"
         return msg
 
     def __hash__(self):
@@ -86,7 +88,7 @@ class AutoModel(ABC):
     _table = None
     _orm = ORM
 
-    __save_memo = []
+    _save_memo = {}
 
     def __new__(cls, *args, **kwargs):
         """
@@ -105,18 +107,16 @@ class AutoModel(ABC):
             obj: The created AutoModel instance.
         """
         obj = super().__new__(cls)
+        pk = kwargs.get("pk", args[0] if args else None)
         # set default attributes
         # Get model data from database
-        result = cls.table().get(kwargs.get("pk")) or {}
+        result = cls.table().get(pk) or {}
         # set object attributes
         for k, v in cls.attributes.items():
-            # set attribute from db or set to default value
-            if isinstance(v, tuple):
-                setattr(obj, k, result.get(k, v[0]))
-            elif isinstance(v, AutoAttribute):
-                setattr(obj, k, result.get(k, v.default))
-            else:
-                setattr(obj, k, result.get(k, v))
+            if isinstance(v, AutoAttribute):
+                v = v.default
+            v = copy.deepcopy(v)
+            setattr(obj, k, result.get(k, v))
 
         # update model with keyword arguments
         obj.__dict__ |= kwargs
@@ -130,6 +130,12 @@ class AutoModel(ABC):
 
         return obj
 
+    def __getattribute__(self, name):
+        obj = super().__getattribute__(name)
+        if isinstance(obj, DelayedModel):
+            return obj._instance()
+        return obj
+
     def __repr__(self) -> str:
         """
         Return a string representation of the AutoModel instance.
@@ -139,11 +145,11 @@ class AutoModel(ABC):
         """
         return f"{self.__dict__}"
 
-    def __getattribute__(self, name):
-        obj = super().__getattribute__(name)
-        if isinstance(obj, DelayedModel):
-            return obj._instance()
-        return obj
+    def __eq__(self, other):
+        return self.pk == other.pk
+
+    def get_save_key(self):
+        return f"{self.__class__.__name__}-{self.pk}"
 
     @classmethod
     def table(cls):
@@ -167,37 +173,51 @@ class AutoModel(ABC):
         """
         return f"{cls.__module__}.{cls.__name__}"
 
-    # @classmethod
-    # def _subobj_save(cls, obj):
+    ## TODO: Save all sub objects
+    ## FIXME: This is causing issues
+    # def _subobj_save(self, obj, key):
     #     if isinstance(obj, list):
     #         for v in obj:
-    #             cls._subobj_save(v)
+    #             if self._subobj_save(v, key) is None:
+    #                 obj.remove(v)
     #     elif isinstance(obj, dict):
-    #         for v in obj.values():
-    #             cls._subobj_save(v)
+    #         for k, v in obj.items():
+    #             if self._subobj_save(v, key) is None:
+    #                 obj[k] = None
     #     elif issubclass(obj.__class__, (AutoModel, DelayedModel)):
-    #         if f"{obj.__class__.__name__}-{obj.pk}" not in AutoModel.__save_memo:
-    #             AutoModel.__save_memo.append(f"{obj.__class__.__name__}-{obj.pk}")
-    #             assert obj._save()
+    #         if not obj.pk:
+    #             obj.pk = str(uuid.uuid4())
+    #         if obj.pk not in self._save_memo[key]:
+    #             obj._save(key)
 
-    def _save(self):
+    def _save(self, key):
         """
         Save this model to the database.
 
         Returns:
             int: The primary key (pk) of the saved model.
-        """
-        log(self.pk, AutoModel.__save_memo, self.__class__.__name__)
 
-        # for k in self.attributes:
-        #     subobj = getattr(self, k)
-        #     self._subobj_save(subobj)
-        if f"{self.__class__.__name__}-{self.pk}" not in AutoModel.__save_memo:
-            AutoModel.__save_memo.append(f"{self.__class__.__name__}-{self.pk}")
-            self.last_updated = datetime.now()
-            record = self.serialize()
-            # log(type(record), record)
-            self.pk = self.table().save(record)
+        ALGO:
+        - add self.pk to save_memo is self.pk
+        - save object not in save memo or without pk into database
+        """
+
+        assert self.pk  # sanity check
+        assert key and key in AutoModel._save_memo  # sanity check
+
+        local_key = self.get_save_key()
+
+        # if key == local_key:
+        #     log(f"Saving root object {key}")
+        # else:
+        #     log(f"Saving child object {local_key} for root {key}")
+
+        if local_key not in AutoModel._save_memo[key]:
+            AutoModel._save_memo[key].append(local_key)
+            self.pk = self.table().save(self.serialize())
+        # FIXME: STILL NOT WORKING
+        # for attr in self.attributes:
+        #     self._subobj_save(getattr(self, attr), key)
         return self.pk
 
     def save(self):
@@ -207,8 +227,14 @@ class AutoModel(ABC):
         Returns:
             int: The primary key (pk) of the saved model.
         """
-        pk = self._save()
-        return pk
+        if not self.pk:
+            self.pk = str(uuid.uuid4())
+        key = self.get_save_key()
+        AutoModel._save_memo[key] = []
+        result = self._save(key)
+        assert result == self.pk
+        AutoModel._save_memo.pop(key)
+        return result
 
     @classmethod
     def get(cls, pk):
@@ -221,9 +247,7 @@ class AutoModel(ABC):
         Returns:
             AutoModel or None: The retrieved AutoModel instance, or None if not found.
         """
-        if isinstance(pk, str) and pk.isdigit():
-            pk = int(pk)
-
+        # breakpoint()
         result = cls.table().get(pk)
         return cls(**result) if result else None
 
@@ -278,10 +302,24 @@ class AutoModel(ABC):
         attribs = cls.table().find(**kwargs)
         return cls(**attribs) if attribs else None
 
-    def delete(self):
+    def _subobj_delete(self, obj):
+        if isinstance(obj, list):
+            for v in obj:
+                self._subobj_delete(v)
+        elif isinstance(obj, dict):
+            for v in obj.values():
+                self._subobj_delete(v)
+        elif issubclass(obj.__class__, (AutoModel, DelayedModel)):
+            obj.delete()
+
+    def delete(self, sub_objects=False):
         """
         Delete this model from the database.
         """
+        if sub_objects:
+            for k in self.attributes:
+                if attr := getattr(self, k):
+                    self._subobj_delete(attr)
         return self.table().delete(pk=self.pk)
 
     serialized_tracker = []
@@ -301,11 +339,18 @@ class AutoModel(ABC):
             val = new_dict
         elif isinstance(val, datetime):
             val = {"_datetime": val.isoformat()}
-        elif issubclass(val.__class__, (AutoModel, DelayedModel)) and val.pk:
-            val = {
-                "pk": val.pk,
-                "_automodel": val.model_name(),
-            }
+        elif issubclass(val.__class__, (AutoModel, DelayedModel)):
+            if val.pk:
+                val = {
+                    "pk": val.pk,
+                    "_automodel": val.model_name(),
+                }
+            else:
+                log(
+                    val.__class__.__name__,
+                    "The above object was not been saved. You must save subobjects if you want them to persist.",
+                )
+                val = None
 
         return val
 
